@@ -236,11 +236,11 @@ class NetworkMapper(Mapper):
 
     @staticmethod
     def validate_update_rest_input(rest_data):
-        NetworkMapper._validate_rest_input(rest_data)
+        NetworkMapper._validate_rest_input(rest_data, check_name=False)
 
     @staticmethod
-    def _validate_rest_input(rest_data):
-        if NetworkMapper.REST_NETWORK_NAME not in rest_data:
+    def _validate_rest_input(rest_data, check_name=True):
+        if check_name and NetworkMapper.REST_NETWORK_NAME not in rest_data:
             raise NetworkNameRequiredDataError()
         Mapper._boolean_or_exception(
             NetworkMapper.REST_PORT_SECURITY_ENABLED,
@@ -482,8 +482,11 @@ class PortMapper(Mapper):
                         subnet_id=PortMapper.REST_PORT_SUBNET_ID
                     )
                 )
-            ip_addr = fixed_ips[0][PortMapper.REST_PORT_IP_ADDRESS]
-            if ip_utils.get_ip_version(ip_addr) is None:
+            ip_addr = fixed_ips[0].get(PortMapper.REST_PORT_IP_ADDRESS)
+            if (
+                    ip_addr is not None and
+                    ip_utils.get_ip_version(ip_addr) is None
+            ):
                 raise RestDataError(
                     'Invalid IP address: {}'.format(ip_addr)
                 )
